#
# LDoms
#
# Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
# The Universal Permissive License (UPL), Version 1.0
#
# Subject to the condition set forth below, permission is hereby
# granted to any person obtaining a copy of this software, associated
# documentation and/or data (collectively the "Software"), free of
# charge and under any and all copyright rights in the Software, and
# any and all patent rights owned or freely licensable by each licensor
# hereunder covering either (i) the unmodified Software as contributed
# to or provided by such licensor, or (ii) the Larger Works (as defined
# below), to deal in both
#
# (a) the Software, and
# (b) any piece of software and/or hardware listed in the lrgrwrks.txt
# file if one is included with the Software (each a "Larger Work" to
# which the Software is contributed by such licensors),
#
# without restriction, including without limitation the rights to copy,
# create derivative works of, display, perform, and distribute the
# Software and make, use, sell, offer for sale, import, export, have
# made, and have sold the Software and the Larger Work(s), and to
# sublicense the foregoing rights on either these or other terms.
#
# This license is subject to the following condition: The above
# copyright notice and either this complete permission notice or at a
# minimum a reference to the UPL must be included in all copies or
# substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#

#
# In order to build the source delivered by the source RPM, the
# following seven variables need to be set to appropriate values
# and then run the three comamnds below (the version and build
# values can be determined from the source RPM numbering).
#
# export PKG_SOURCE="$HOME/rpmbuild/SOURCES"
# export PKG_VERSION=3.5.0.0
# export PKG_RELEASE=23.2343
# export PKG_BUILD=1
# export PKG_FULL_VER=$PKG_VERSION-$PKG_RELEASE.$PKG_BUILD
# export LDM_WORKSPACE=$PKG_SOURCE/ldomsmanager-$PKG_FULL_VER
# export RPM_ROOT=${LDM_WORKSPACE}/rpm
#
# cd $PKG_SOURCE
# tar xf ldomsmanager-$PKG_FULL_VER.tar
# ksh ldomsmanager-$PKG_FULL_VER/tools/zeus_nightly.ksh -w $PKG_SOURCE/ldomsmanager-$PKG_FULL_VER
#
# In the future, we should look at doing this in the 'build' section.
#

Summary: Logical Domains Manager
Name: ldomsmanager%{?_variant}
Version: %{_version}
Release: %{_ldomsbuild}%{?dist}
Group: System Environment/Daemons
Vendor: Oracle America
License: UPL

Source0: ldomsmanager-%{version}-%{_ldomsbuild}.tar

BuildRequires: bind-devel
BuildRequires: cyrus-sasl-devel
BuildRequires: devtoolset-3-gcc
BuildRequires: dtrace-utils
BuildRequires: glibc-devel
BuildRequires: ksh
BuildRequires: libuuid-devel
BuildRequires: libxml2-devel
BuildRequires: mercurial >= 3.0
BuildRequires: openssl-devel
BuildRequires: pam-devel
BuildRequires: rpm-build
BuildRequires: rpmlint
BuildRequires: zlib-devel
Conflicts: ldomsmanager%{!?_variant:-debug}
Requires: bind-libs
Requires: bridge-utils
Requires: cyrus-sasl-lib
Requires: cyrus-sasl-plain
Requires: engine_pkcs11
Requires: glibc
#
# We have a dependency on kernel-uek 4.1.8-15 (Linux for SPARC 1.0)
# Requires: kernel-uek >= 4.1.8-15
# or
# kernel-uek 2.6.39-500.1.40 (Exadata Beta 2)
# Requires: kernel-uek >= 2.6.39-500.1.40
# to ensure we have the required LDoms drivers (vldc and co).
# We cannot do multiple conditionals so we pick the lowest version
# (at the risk that older UEK4 builds would also be accepted but
#  won't have all the support)
#
Requires: kernel-uek >= 2.6.39-500.1.40
Requires: ldoms
Requires: libuuid
Requires: libxml2
Requires: opensc
#
# We require openssl-devel (and not just openssl) because we need
# libssl.so which is only provided with openssl-devel (openssl
# provides libssl.so.* but not libssl.so)
#
Requires: openssl-devel
Requires: pam
Requires: zlib

#
# NetworkManager can cause adverse effects in an LDoms environment (both
# with virtual switches and the SP interconnect). We exclude the package
# as NetworkManager is not appropriate in a server environment.
#
Conflicts: NetworkManager

Provides: ldomsmanager = %{version}

# Use BuildRoot provided to rpmbuild on command line
BuildRoot: %{buildroot}

%description
Oracle VM Server for SPARC - Virtualization for SPARC M-Series and T-Series

%build

%install
rm -rf %{buildroot}
mkdir %{buildroot}
cp -rp %{_root}/* %{buildroot}

%clean
rm -rf %{buildroot}

%pre

%prep

%post
case "$1" in
  1)
    # Initial install - add service
    /sbin/chkconfig --add ldmd
    ;;
  2)
    # Upgrade - delete and re-add the service.
    /sbin/chkconfig --del ldmd
    /sbin/chkconfig --add ldmd
    ;;
esac

%preun
case "$1" in
  0)
    # Uninstall
    /sbin/service ldmd stop
    /sbin/chkconfig --del ldmd
    ;;
esac

%postun

%files
%defattr(-,root,root,-)
%doc
/etc/init.d/ldmd
/etc/pam.d/ldmd
/opt/SUNWldm/bin/ldmd
/opt/SUNWldm/lib/ds/dr_cpu-1.0_lib.so
/opt/SUNWldm/lib/ds/dr_crypto-1.0_lib.so
/opt/SUNWldm/lib/ds/dr_mem-1.0_lib.so
/opt/SUNWldm/lib/ds/dr_pdom-1.0_lib.so
/opt/SUNWldm/lib/ds/dr_vio-1.0_lib.so
/opt/SUNWldm/lib/ds/ds_adev-1.0_lib.so
/opt/SUNWldm/lib/ds/ds_asysad-1.0_lib.so
/opt/SUNWldm/lib/ds/ds_dio-1.0_lib.so
/opt/SUNWldm/lib/ds/ds_netsvc-1.0_lib.so
/opt/SUNWldm/lib/ds/ds_vhba-1.0_lib.so
/opt/SUNWldm/lib/ds/ds_vmapi-1.0_lib.so
/opt/SUNWldm/lib/ds/keystore-1.0_lib.so
/opt/SUNWldm/lib/ds/keystore_backup-1.0_lib.so
/opt/SUNWldm/lib/ds/mdstore-1.0_lib.so
/opt/SUNWldm/lib/ds/platsvc-1.0_lib.so
/opt/SUNWldm/lib/ds/pri_svc-1.0_lib.so
/opt/SUNWldm/lib/ds/varconfig-1.0_lib.so
/opt/SUNWldm/lib/ds/varconfig_backup-1.0_lib.so
/opt/SUNWldm/lib/libmodel.so
/opt/SUNWldm/lib/templates/guest-state-v1.bin
/opt/SUNWldm/lib/templates/guest-state-v2.bin
/opt/SUNWldm/lib/templates/ldc-state-v1.bin
/opt/SUNWldm/lib/templates/ldc-state-v2.bin
/opt/SUNWldm/lib/templates/vcpu-state-v1.bin
/opt/SUNWldm/lib/templates/vcpu-state-v2.bin
/usr/sbin/ldm
/usr/share/doc/ldomsmanager/LICENSE

%changelog
